from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / "README.md").read_text(encoding="utf-8")

setup(
    name="teleconnector",
    version="0.1.0",
    author="Your Name",
    author_email="mrfidal@proton.me",
    description="Easily connect console or code to Telegram groups/channels",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bytebreach/teleconnector",
    license="MIT",
    packages=find_packages(),
    install_requires=[
        "python-telegram-bot>=20.0"
    ],
    python_requires=">=3.9",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Communications :: Chat",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    entry_points={
        "console_scripts": [
            "teleconnector-cli=teleconnector.cli:main",
        ]
    },
)
